%% RunSettings_CarInsurance
% function that provides the settings for running the desired estimation
% Each row in NumRunSettings corresponds to the input settings for a single
% estimation run
% Written by Bart Frischknecht, first version 29 March 2013, 
% Edits:
%
%%%%%%%%%%%%%%%%%%%%%%%

%% INPUTS
% Variable          Dimension                       Units                   Description
% N                 scalar                          individuals             Number of individuals in the sample
% PriorType         scalar                          -                       An index identifying the type of conjugate prior to use in estimation     
%                                                                           1=flat prior; 2=empirical Bayes prior; 3=flat prior with market relevant
%                                                                           choice sets
% S                 scalar                          choice sets             Number of choice sets faced by each individual
% alpha_guess       scalar                          -                       Guess for relative weight of the prior compared to the original data
% Vee               scalar                          -                       The number of validation subsample replications for a particular prior
%                                                                           weight ratio
% PercSamp          scalar                          -                       The percentage of the sample randomly drawn as the validation subsample for 
%                                                                           a particular replication vee=1, ..., Vee
% L                 scalar                          -                       The number of prior weight values to search. Prior weight values are 
%                                                                           logarithmically centered around alpha_guess
% alpha_max         scalar                          -                       The maximum prior weight to test. Note, when L is odd and greater than 1, 
%                                                                           then alpha_max will be included in the prior weights tested. When L is 
%                                                                           even then the largest alpha tested will be smaller than alpha_max
% Plot              scalar                          -                       An indicator that turns plotting on (Plot=1) or turns plotting off
%                                                                           (Plot=0)
% indindexon        scalar                          -                       An indicator that turns on reporting an individual index during
%                                                                           estimation. This allows the user to observe the progress through the
%                                                                           individual estimations for each prior weight value tested
%
%%%%%%%%%%%%%%%%%%%%%%%

%% OUTPUTS
%
% NumRunSettings    R x 9 matrix                    -                       Input settings for each estimation run. Each row is describes one run, r=1, ..., R.
%                                                                           The specific variables are described in the INPUT section
%
%%%%%%%%%%%%%%%%%%%%%%%

function NumRunSettings= RunSettings_CarInsurance()

                %N    PriorType S  alpha_guess  Vee PercSamp L    alpha_max Plot    indindexon   
NumRunSettings=[200   1         12  .2          10  .5       15   10        1       1           %1
                200   2         12  .2          10  .5       15   10        1       1           %2
                200   3         12  .2          10  .5       15   10        1       1           %3
              ];

